.. currentmodule:: flox

API Reference
-------------

Functions
~~~~~~~~~

.. autosummary::
    :toctree: generated/

    ~core.groupby_reduce
    xarray.xarray_reduce

Rechunking
~~~~~~~~~~

.. autosummary::
    :toctree: generated/

    ~core.rechunk_for_blockwise
    ~core.rechunk_for_cohorts
    xarray.rechunk_for_blockwise
    xarray.rechunk_for_cohorts

Visualization
~~~~~~~~~~~~~

.. autosummary::
    :toctree: generated/

    visualize.draw_mesh
    visualize.visualize_groups
    visualize.visualize_cohorts_2d

Aggregation Objects
~~~~~~~~~~~~~~~~~~~

.. autosummary::
    :toctree: generated/

    aggregations.Aggregation
    aggregations.sum
    aggregations.nansum
